@@ -414,8 +414,9 @@ class Model:
             for style in self.styles:
                 if style.row > sizetable[0]:
                     style.row = style.row + sizetable[1]
+        styles = self.styles
         for sizetable in sizetables:
-            for style in self.styles:
+            for style in styles:
                 if style.row == sizetable[0]:
                     for n in range(sizetable[1]):
                         self.__styles.append(Style(style.name,style.row+n,style.column,style.data_type, style.font, style.alignment,style.fill, style.border))
@@ -435,8 +436,8 @@ class Model:
                 for table in data['table']:
                     if variable.name in table:
                         variable.value = table[variable.name]
-                            
-        for variable in self.variables:
+        variables = self.variables
+        for variable in variables:
             if 'table' in data:
                 n=0
                 for table in data['table']:
